import java.util.List;

import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.iwomedia.zhaoyang.bean.Article;
import com.iwomedia.zhaoyang.util.TimeUtil;
import com.iwomedia.zhigu.R;

/**
 * 文章列表适配器
 */
public class HotArticleAdapter extends BaseAdapter {
	private String  TAG = "HotArticleAdapter";
	private List<Article> articleList;
	private Context mContext;
	private ViewHolder holder;

	public HotArticleAdapter(Context context, List<Article> articleList) {
		super();
		mContext = context;
		this.articleList = articleList;
	}

	@Override
	public int getCount() {
		return articleList == null ? 0 : articleList.size();
	}

	@Override
	public Object getItem(int position) {
		return articleList.get(position);
	}

	@Override
	public long getItemId(int position) {
		return position;
	}

	@Override
	public View getView(int position, View convertView, ViewGroup parent) {
		final Article article = articleList.get(position);
		holder = null;
        if(convertView == null)
        {
            holder = new ViewHolder();
            convertView = View.inflate(mContext, R.layout.hot_article_item, null);
            
            holder.titleTv = (TextView) convertView.findViewById(R.id.tv_title);
            holder.coverPhotoImg = (ImageView)convertView.findViewById(R.id.iv_photo);
            holder.publishTimeTv = (TextView)convertView.findViewById(R.id.tv_publish_time);
            holder.zanIv = (ImageView) convertView.findViewById(R.id.iv_zan);
            holder.zanNumTv = (TextView)convertView.findViewById(R.id.tv_zan_num);
            holder.messageIv = (ImageView) convertView.findViewById(R.id.iv_message);
            holder.messageNumTv = (TextView)convertView.findViewById(R.id.tv_message_num);
            
            convertView.setTag(holder);
            
        }else{
            holder = (ViewHolder)convertView.getTag();
        }
        
		ImageMgmr.showImage(holder.coverPhotoImg, article.getCover_url(), 
				R.drawable.loading_middle, 
				R.drawable.loading_middle, 
				null, 
				SB.display.dip2px(100), 
				SB.display.dip2px(100), 
				true, 
				true);
		
        holder.titleTv.setText(article.getTitle());
        holder.publishTimeTv.setText(TimeUtil.getDateString(article.getInstime(), "yyyy-MM-dd hh:mm"));
        holder.zanNumTv.setText(article.getZan_nums());
        holder.messageNumTv.setText(article.getComment_nums());
        
        holder.zanNumTv.setTag(article.getId()+"zan");
        holder.messageNumTv.setTag(article.getId()+"comment");
        
        //获取追踪状态字符
        String	isFollowedStr = article.getIs_followed();
        //根据跟踪状态显示不同的图标
        if(isFollowedStr != null &&!"".equals(isFollowedStr))
        {
        	int is_followed = Integer.parseInt(article.getIs_followed());
        	
        	if(is_followed == 0){
        		article.setIs_followed("0");
        		holder.zanIv.setSelected(false);
        	}else{
        		article.setIs_followed("1");
        		holder.zanIv.setSelected(true);
        	}
        }
        
        return convertView;
		
		
	}
	
	class ViewHolder{
		/**
		 * 标题
		 */
		private TextView titleTv;
		/**
		 * 封面图片
		 */
		private ImageView coverPhotoImg;
		
		/**
		 * 发布时间
		 */
		private TextView publishTimeTv;
		/**
		 * 赞的icon
		 */
		private ImageView zanIv;
		/**
		 * 赞的数量
		 */
		private TextView zanNumTv;
		
		/**
		 * 消息的icon
		 */
		private ImageView messageIv;
		/**
		 * 消息的数量
		 */
		private TextView messageNumTv;
		
//		/**
//		 * 跟踪状态 已跟踪：1， 未跟踪：0
//		 */
//		private boolean traceStatus = false;
	}

	public List<Article> getArticleList() {
		return articleList;
	}

	public void setArticleList(List<Article> articleList) {
		this.articleList = articleList;
	}

	public void notifyDataSetChanged(List<Article> arts) {
		this.articleList = arts;
		super.notifyDataSetChanged();
		
	}

}