import android.content.Context;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;

import com.iwomedia.zhigu.R;


/**
 * 在fragment的activity中使用,就是一个title bar
 * 
 */
public class LayoutForTitle extends FrameLayout implements OnClickListener {

	/**
	 * 左右按钮
	 */
	private ImageView leftbutton, rightbutton;

	/**
	 * 标题内容
	 */
	private TextView title;

	/**
	 * 左右,标题三个控件的监听事件,调用者传过来就可以执行指定的事件处理过程
	 */
	private OnClickListener mOnLeftClickListener;
	private OnClickListener mOnRightClickListener;
	private OnClickListener mOnTitleClickListener;

	public LayoutForTitle(Context context, AttributeSet attrs) {
		super(context, attrs);
		initTitleView(context);
	}

	public interface OnLeftClickListener {
		public void onClick(View view);
	}

	public interface OnRightClickListener {
		public void onClick(View view);
	}

	public interface OnTitleClickListener {
		public void onClick(View view);
	}

	private void initTitleView(Context context) {
		LayoutInflater inflater = (LayoutInflater) context
				.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
		inflater.inflate(R.layout.title_bar, this);
		leftbutton = (ImageView) findViewById(R.id.left_btn);
		rightbutton = (ImageView) findViewById(R.id.right_btn);
		title = (TextView) findViewById(R.id.title);

		leftbutton.setOnClickListener(this);
		rightbutton.setOnClickListener(this);

		/**
		 * 初始化时将按钮隐藏掉
		 */
		leftbutton.setVisibility(View.GONE);
		rightbutton.setVisibility(View.GONE);
	}


	/**
	 * 设置标题和左右两边的按钮
	 * @param title
	 * @param leftPictureResourceId
	 * @param onLeft
	 * @param rightPictureResourceId
	 * @param onRight
	 */
	public void setTitleAndBothButton(String title, int leftPictureResourceId , OnClickListener onLeft,
			int rightPictureResourceId , OnClickListener onRight) {
		if (leftPictureResourceId != 0) {
			leftbutton.setImageResource(leftPictureResourceId);
			leftbutton.setVisibility(View.VISIBLE);
			mOnLeftClickListener = onLeft;
		}
		if (rightPictureResourceId != 0) {
			rightbutton.setImageResource(rightPictureResourceId);
			rightbutton.setVisibility(View.VISIBLE);
			mOnRightClickListener = onRight;
		}
		
		setTitle(title);
	}
	
	/**
	 * 设置标题和左右两边的按钮
	 * @param title
	 * @param leftPictureResourceId
	 * @param onLeft
	 * @param rightPictureResourceId
	 * @param onRight
	 */
	public void setTitleAndBothButton(int title, int leftPictureResourceId , OnClickListener onLeft,
			int rightPictureResourceId , OnClickListener onRight) {
		if (leftPictureResourceId != 0) {
			leftbutton.setImageResource(leftPictureResourceId);
			leftbutton.setVisibility(View.VISIBLE);
			mOnLeftClickListener = onLeft;
		}
		if (rightPictureResourceId != 0) {
			rightbutton.setImageResource(rightPictureResourceId);
			rightbutton.setVisibility(View.VISIBLE);
			mOnRightClickListener = onRight;
		}
		
		setTitle(title);
	}
	
	
	/**
	 * 单独设置标题信息
	 * @param text
	 */
	public void setTitle(String text) {
		title.setText(text);
	}

	/**
	 * 单独设置标题信息
	 * @param text
	 */
	public void setTitle(int text) {
		title.setText(text);
	}

	/**
	 * 单独设置标题信息
	 * @param text
	 * @param listener
	 */
	public void setTitle(String text, OnClickListener listener) {
		title.setText(text);
		mOnTitleClickListener = listener;
	}

	/**
	 * 单独设置标题信息
	 * @param text
	 * @param listener
	 */
	public void setTitle(int text, OnClickListener listener) {
		title.setText(text);
		mOnTitleClickListener = listener;
	}

	/**
	 * 单独设置左边按钮
	 * @param drawable
	 * @param listener
	 */
	public void setLeftButton(Drawable drawable, OnClickListener listener) {
		leftbutton.setImageDrawable(drawable);
		leftbutton.setVisibility(View.VISIBLE);
		mOnLeftClickListener = listener;
	}

	/**
	 * 单独设置左边按钮
	 * @param imageResourceId
	 * @param listener
	 */
	public void setLeftButton(int imageResourceId, OnClickListener listener) {
		leftbutton.setImageResource(imageResourceId);
		leftbutton.setVisibility(View.VISIBLE);
		mOnLeftClickListener = listener;
	}
	
	/**
	 * 单独设置左边按钮
	 * @param imageResourceId
	 * @param picid
	 * @param listener
	 */
	public void setLeftButton(int imageResourceId, int picid,
			OnClickListener listener) {
		leftbutton.setImageResource(imageResourceId);
		leftbutton.setBackgroundResource(picid);
		leftbutton.setVisibility(View.VISIBLE);
		mOnLeftClickListener = listener;
	}
	
	
	/**
	 * 单独设置右边按钮
	 * @param drawable
	 * @param listener
	 */
	public void setRightButton(Drawable drawable, OnClickListener listener) {
		rightbutton.setImageDrawable(drawable);
		rightbutton.setVisibility(View.VISIBLE);
		mOnRightClickListener = listener;
	}

	
	/**
	 * 单独设置右边按钮
	 * @param imageResourceId
	 * @param listener
	 */
	public void setRightButton(int imageResourceId,
			OnClickListener listener) {
		rightbutton.setImageResource(imageResourceId);
		rightbutton.setVisibility(View.VISIBLE);
		mOnRightClickListener = listener;
	}

	
	/**
	 * 单独设置右边按钮
	 * @param imageResourceId
	 * @param picid
	 * @param listener
	 */
	public void setRightButton(int imageResourceId, int picid,
			OnClickListener listener) {
		rightbutton.setImageResource(imageResourceId);
		rightbutton.setBackgroundResource(picid);
		rightbutton.setVisibility(View.VISIBLE);
		mOnRightClickListener = listener;
	}

	@Override
	public void onClick(View v) {
		switch (v.getId()) {
		case R.id.left_btn:
			if (mOnLeftClickListener != null) {
				mOnLeftClickListener.onClick(v);
			}
			break;
		case R.id.right_btn:
			if (mOnRightClickListener != null) {
				mOnRightClickListener.onClick(v);
			}
			break;
		case R.id.title:
			if (mOnTitleClickListener != null) {
				mOnTitleClickListener.onClick(v);
			}
			break;
		}

	}

}
